 
% This file contains additional materials for 
% "Redistribution and Social Insurance".
% 
% This file constructs 3 sets of
% initial period distortions and their decompositions
% for increasing values of kurtosis.
% This file uses quasilinear preferences.
% 
% The pareto-lognormal pdf and cdf files need to be 
% already in the same directory.
% 
% The .eps files are saved at the end 
% and existing files would be replaced.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
close all;

epsilon = 0.5;
kappa=0.9;

%LN distribution parameters
mu=0;
sigma=1;

%PLN distribution parameters alpha=2
alpha=2;
nu=-0.5;
tau=0.87;

%PLN distribution parameters alpha=2.5
alpha2=2.5;
nu2=-0.4;
tau2=0.92;

%MLN distribution parameters
k2=13;
k3=9;
k4=15;

sigma2=2.2;
sigma3=2.4;
sigma4=2.6;

sigma22=2.2;
sigma32=2.0;
sigma42=2.4;

%display parameters
lw = 3;
Font = 24;
FontN='Times New Roman';
fout1 = 'kurtosis2';



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%probability of LN(0,sigma1) in the MLN

tic
sigma21=[(sigma22^4-k2/3)/(sigma22^2-1)-sigma22^2]^0.5;
sigma31=[(sigma32^4-k3/3)/(sigma32^2-1)-sigma32^2]^0.5;
sigma41=[(sigma42^4-k4/3)/(sigma42^2-1)-sigma42^2]^0.5;


p2=(sigma22^2-1)/(sigma22^2-sigma21^2);
p3=(sigma32^2-1)/(sigma32^2-sigma31^2);
p4=(sigma42^2-1)/(sigma42^2-sigma41^2);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%PDF and CDF functions

pdf_ln   = @(x) pdf('logn',x,mu,sigma);
pdf_mln2 = @(x) p2*pdf('logn',x,mu,sigma21)+(1-p2)*pdf('logn',x,mu,sigma22);
pdf_mln3 = @(x) p3*pdf('logn',x,mu,sigma31)+(1-p3)*pdf('logn',x,mu,sigma32);
pdf_mln4 = @(x) p4*pdf('logn',x,mu,sigma41)+(1-p4)*pdf('logn',x,mu,sigma42);
pdf_pln  = @(x) plognpdf(x, alpha, nu, tau);
pdf_pln2 = @(x) plognpdf(x, alpha2, nu2, tau2);


cdf_ln   = @(x) cdf('logn',x,mu,sigma);
cdf_mln2 = @(x) p2*cdf('logn',x,mu,sigma21)+(1-p2)*cdf('logn',x,mu,sigma22);
cdf_mln3 = @(x) p3*cdf('logn',x,mu,sigma31)+(1-p3)*cdf('logn',x,mu,sigma32);
cdf_mln4 = @(x) p4*cdf('logn',x,mu,sigma41)+(1-p4)*cdf('logn',x,mu,sigma42);
cdf_pln  = @(x) plogncdf(x, alpha, nu, tau);
cdf_pln2 = @(x) plogncdf(x, alpha2, nu2, tau2);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%inverse hazard ratios

haz_ln=@(x) (1-cdf_ln(x))./pdf_ln(x)./x; 
haz_mln2=@(x) (1-cdf_mln2(x))./pdf_mln2(x)./x;
haz_mln3=@(x) (1-cdf_mln3(x))./pdf_mln3(x)./x;
haz_mln4=@(x) (1-cdf_mln4(x))./pdf_mln4(x)./x;
haz_pln=@(x) (1-cdf_pln(x))./pdf_pln(x)./x;
haz_pln2=@(x) (1-cdf_pln2(x))./pdf_pln2(x)./x;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%grid
%the first value is given by int*initial

int=0.1;
initial=0.1; 
T=20;
gridd=[initial*int:int:T];

%{
%inverse hazard on the grid
figure(1) 
plot(gridd,haz_ln(gridd),gridd,haz_mln2(gridd),gridd,haz_mln3(gridd),gridd,haz_mln4(gridd),gridd,haz_pln(gridd),gridd,haz_pln2(gridd));
title('inverse hazard rates');
legend('LN','MLN2','MLN3','MLN4','PLN a=2','PLN a=2.5');
%}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%defining functions (integrands) to determine a's

%LN=@(x) x.^(-kappa).*pdf_ln(x);
LN=@(x) exp(-x).*pdf_ln(x);
MLN2=@(x) x.^(-kappa).*pdf_mln2(x);
%MLN3=@(x) x.^(-kappa).*pdf_mln3(x);
MLN3=@(x) exp(-x).*pdf_mln3(x);
%MLN4=@(x) x.^(-kappa).*pdf_mln4(x);
MLN4=@(x) exp(-x).*pdf_mln4(x);
PLN=@(x) x.^(-kappa).*pdf_pln(x);
%PLN2=@(x) x.^(-kappa).*pdf_pln2(x);
PLN2=@(x) exp(-x).*pdf_pln2(x);


%integrals
Q_LN=@(x) quadgk(LN,x,inf);
Q_MLN2=@(x) quadgk(MLN2,x,inf);
Q_MLN3=@(x) quadgk(MLN3,x,inf);
Q_MLN4=@(x) quadgk(MLN4,x,inf);
Q_PLN=@(x) quadgk(PLN,x,inf);
Q_PLN2=@(x) quadgk(PLN2,x,inf);


%a's
a_LN=1/Q_LN(0);
a_MLN2=1/Q_MLN2(0);
a_MLN3=1/Q_MLN3(0);
a_MLN4=1/Q_MLN4(0);
a_PLN=1/Q_PLN(0);
a_PLN2=1/Q_PLN2(0);


%last integral (integrand)
%In_LN=@(x) (1-a_LN.*x.^(-kappa)).*pdf_ln(x);
In_LN=@(x) (1-a_LN.*exp(-x)).*pdf_ln(x);
In_MLN2=@(x) (1-a_MLN2.*x.^(-kappa)).*pdf_mln2(x);
%In_MLN3=@(x) (1-a_MLN3.*x.^(-kappa)).*pdf_mln3(x);
In_MLN3=@(x) (1-a_MLN3.*exp(-x)).*pdf_mln3(x);
%In_MLN4=@(x) (1-a_MLN4.*x.^(-kappa)).*pdf_mln4(x);
In_MLN4=@(x) (1-a_MLN4.*exp(-x)).*pdf_mln4(x);
In_PLN=@(x) (1-a_PLN.*x.^(-kappa)).*pdf_pln(x);
%In_PLN2=@(x) (1-a_PLN2.*x.^(-kappa)).*pdf_pln2(x);
In_PLN2=@(x) (1-a_PLN2.*exp(-x)).*pdf_pln2(x);


%last integral
INT_LN=@(x) quadgk(In_LN,x,inf)./(1-cdf_ln(x));
INT_MLN2=@(x) quadgk(In_MLN2,x,inf)./(1-cdf_mln2(x));
INT_MLN3=@(x) quadgk(In_MLN3,x,inf)./(1-cdf_mln3(x));
INT_MLN4=@(x) quadgk(In_MLN4,x,inf)./(1-cdf_mln4(x));
INT_PLN=@(x) quadgk(In_PLN,x,inf)./(1-cdf_pln(x));
INT_PLN2=@(x) quadgk(In_PLN2,x,inf)./(1-cdf_pln2(x));


%integrals on the gridd
for i=1:length(gridd)
    int_ln(i)=INT_LN(gridd(i));
    int_mln2(i)=INT_MLN2(gridd(i));
    int_mln3(i)=INT_MLN3(gridd(i));
    int_mln4(i)=INT_MLN4(gridd(i));
    int_pln(i)=INT_PLN(gridd(i));
    int_pln2(i)=INT_PLN2(gridd(i));
end

%{
integrals on the gridd
figure(2) 
plot(gridd,int_ln,gridd,int_mln2,gridd,int_mln3,gridd,int_mln4,gridd,int_pln,gridd,int_pln2);
title('integrals');
legend('LN','MLN2','MLN3','MLN4','PLN a=2','PLN a=2.5');
%}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%distortions

tax_pr_ln = (1+1/epsilon)*haz_ln(gridd).*int_ln;
tax_pr_pln2 = (1+1/epsilon)*haz_pln2(gridd).*int_pln2;
tax_pr_mln4 = (1+1/epsilon)*haz_mln4(gridd).*int_mln4;
tax_pr_mln3 = (1+1/epsilon)*haz_mln3(gridd).*int_mln3;

tax_ln = tax_pr_ln./(1+tax_pr_ln);
tax_pln2 = tax_pr_pln2./(1+tax_pr_pln2);
tax_mln4 = tax_pr_mln4./(1+tax_pr_mln4);
tax_mln3 = tax_pr_mln3./(1+tax_pr_mln3);


%averages
tax_ave_ln = (tax_ln*pdf_ln(gridd)')/(ones(1, length(gridd))*pdf_ln(gridd)');
tax_ave_pln2 = (tax_pln2*pdf_pln2(gridd)')/(ones(1, length(gridd))*pdf_pln2(gridd)');
tax_ave_mln3 = (tax_mln3*pdf_mln3(gridd)')/(ones(1, length(gridd))*pdf_mln3(gridd)');
tax_ave_mln4 = (tax_mln4*pdf_mln4(gridd)')/(ones(1, length(gridd))*pdf_mln4(gridd)');
toc


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure  ('units','normalized','outerposition',[0 0 .95 1])  
%figure  ('units','normalized','outerposition',[0 .1 1 .7]) 


%%%%%%%%%
subplot(2,3,1)
hold on
box on
grid on

plot(gridd, haz_ln(gridd), '-.b', gridd, int_ln, 'k--','LineWidth',lw)

legend('B_0','C_0','location','northeast');
legend boxoff;
%xlabel('\theta')
%ylabel('\tau/(1-\tau), hazard')
axis([0 T 0 2.1])
set(gca,'XTick',0:5:T);
title('A: Lognormal')


%%%%%%%%%
subplot(2,3,2)
hold on
box on
grid on

plot(gridd, haz_mln3(gridd), '-.b', gridd, int_mln3, 'k--','LineWidth',lw)

axis([0 T 0 2.1])
set(gca,'XTick',0:5:T);
title('B: Low kurtosis mixture')


%%%%%%%%%
subplot(2,3,3)
hold on
box on
grid on

plot(gridd, haz_mln4(gridd), '-.b', gridd, int_mln4, 'k--','LineWidth',lw)

axis([0 T 0 2.1])
set(gca,'XTick',0:5:T);
%xlabel('\theta')
%ylabel('\tau/(1-\tau), hazard')
title('C: High kurtosis mixture')


%%%%%%%%%
subplot(2,3,4)
hold on
box on
grid on

plot(gridd, tax_ln, '-r', 'LineWidth',lw)
plot(gridd, tax_ave_ln.*(ones(1, length(gridd))), 'r--','LineWidth',lw/3)

xlabel('\theta')
%ylabel('\tau')
legend('\tau^y_0','average \tau^y_0','location','northeast');
legend boxoff;
axis([0 T 0.4 1])
set(gca,'XTick',0:5:T);
title('D: Lognormal')


%%%%%%%%%
subplot(2,3,5)
hold on
box on
grid on

plot(gridd, tax_mln3, '-r', 'LineWidth',lw)
plot(gridd, tax_ave_mln3.*(ones(1, length(gridd))), 'r--','LineWidth',lw/3)

xlabel('\theta')
axis([0 T 0.4 1])
set(gca,'XTick',0:5:T);
title('E: Low kurtosis mixture')


%%%%%%%%%
subplot(2,3,6)
hold on
box on
grid on

plot(gridd, tax_mln4, '-r', 'LineWidth',lw)
plot(gridd, tax_ave_mln4.*(ones(1, length(gridd))), 'r--','LineWidth',lw/3)

xlabel('\theta')
%ylabel('\tau')
axis([0 T 0.4 1])
set(gca,'XTick',0:5:T);
title('F: High kurtosis mixture')



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
saveas(gcf,fout1,'fig')
set(findall(gcf,'type','text'),'FontSize',Font,'FontName',FontN);
set(findall(gcf,'type','axes'),'FontSize',Font,'FontName',FontN);
set(gcf,'PaperPositionMode','auto');
print (gcf, '-depsc', fout1);
clear all;
close all;


