

% This file contains additional materials for 
% "Redistribution and Social Insurance".
% 
% This file constructs decompositions into
% intertemporal and intratemporal forces 
% for 2 sets of 3 histories
% from allocation .out files, 
% plots the decomositions in the baseline case.
% 
% The allocation .out files need to be located 
% in the same directory.
% 
% The .eps files are saved at the end 
% and existing files would be replaced.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
close all;

% parameters

eps=0.5; %0.25;
rho=1; %0.957;
file0  = 'ceslog'; %'ceslog-logn';

lw = 3;
Font = 22;
FontN='Times New Roman';



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% low histories

file1  = strcat('e05-base-1-');
file2  = strcat('e05-base-20-');
file3  = strcat('e05-base-39-');

I1=9;I2=12;

fext   = '.out';
fout1  = strcat('decompositions-',file0,file1,'I',num2str(I1));



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% construct low history 1

file=file1;

% lifetime variables
fend = 'In';
out = dlmread(strcat(file0,file,fend,fext));

thym  = out(:,1);
thm   = out(:,2)/10*2;
gm    = out(:,4:size(out,2));
In   = length(thym);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(file0,file,fend,fext));

uc_m = out(:,1);
tau_m= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(I1)); 
out  = dlmread(strcat(file0,file,fend,fext));

uctm = out(:,1);
tautm= out(:,2);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% construct low history 2

file=file2;

% lifetime variables
fend = 'In';
out = dlmread(strcat(file0,file,fend,fext));

thyp  = out(:,1);
thp   = out(:,2)/10*2;
gp    = out(:,4:size(out,2));
In   = length(thyp);
clear out;

% preceeding variables
fend = 'm'; 
out  = dlmread(strcat(file0,file,fend,fext));

uc_p = out(:,1);
tau_p= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(I1)); 
out  = dlmread(strcat(file0,file,fend,fext));

uctp = out(:,1);
tautp= out(:,2);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% construct low history 3

file=file3;

% lifetime variables
fend = 'In';
out = dlmread(strcat(file0,file,fend,fext));

thy  = out(:,1);
th   = out(:,2)/10*2;
g    = out(:,4:size(out,2));
In   = length(thy);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(file0,file,fend,fext));

uc_ = out(:,1);
tau_= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(I1)); 
out  = dlmread(strcat(file0,file,fend,fext));

uct = out(:,1);
taut= out(:,2);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compute low histories' terms
% (for tau close to 1 divisions increase 
% numerical errors significantly,
% choose option below to filter)

Tautm = tautm./(ones(In,1)-tautm);
Tautp = tautp./(ones(In,1)-tautp);
Taut  = taut ./(ones(In,1)-taut );

G = g(:,I1);
for i=2:In
    G(i)=G(i-1)+G(i);
end
Gc    = ones(In,1)-G;
H     = Gc./(g(:,I1).*th);

Uctm   = uc_m./uctm(I1);
Uctp   = uc_p./uctp(I1);
Uct    = uc_ ./uct(I1);

Tautmm   = tau_m(I1)/(1-tau_m(I1));
Tautpm   = tau_p(I1)/(1-tau_p(I1));
Taut_m   = tau_(I1)/(1-tau_(I1));

Tautmterm = rho*Tautmm*Uctm;
Tautpterm = rho*Tautpm*Uctp;
Taut_term = rho*Taut_m*Uct;

Intratm = Tautm - Tautmterm;
Intratp = Tautp - Tautpterm;
Intrat  = Taut  - Taut_term;

% option: filter exacerbated approximation errors after divisions
Ctm = smooth(Intratm/(1+1/eps)./H,3,'moving');
Ctp = smooth(Intratp/(1+1/eps)./H,3,'moving');
Ct  = smooth(Intrat /(1+1/eps)./H,3,'moving');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure  ('units','normalized','outerposition',[0 0 .75 1])  
%figure  ('units','normalized','outerposition',[0 .1 .4 .7])


%%%%%%
subplot(2,2,2)
hold on
grid on
box on

plot(thy,Uct,'-r','LineWidth',lw);
plot(thyp,Uctp,'--b','LineWidth',lw);
plot(thym,Uctm,'-.k','LineWidth',lw);

axis tight
xlim([thy(1) thy(In-3)]);
ylim([0 5.7]);
legend('D_{39}','D_{20}','D_1','location','northeast');
legend boxoff
%xlabel('Labor earnings, $1000s');
title({'B: Intertemporal forces,','history of low earnings'});


%%%%%%
subplot(2,2,1)
hold on
grid on
box on

ph1 = plot(thy,H,'-.k','LineWidth',lw);
ph2 = plot(thy,Ct,'-r','LineWidth',lw/2);
ph3 = plot(thyp,Ctp,'--b','LineWidth',lw/2);
ph4 = plot(thym,Ctm,'-.k','LineWidth',lw/2);

axis tight
xlim([thy(1) thy(In-3)]);
ylim([0 5.7]);
%xlabel('Labor earnings, $1000s');
%legendstr = {'B_t';'C_{39}';'C_{20}';'C_1'};
%legend(legendstr,'location','northeast');
title({'A: Intratemporal forces,','history of low earnings'});


legend(   ph1(1),'B_t',   'location',[0.26,0.77,0.1,0.1]); legend boxoff;
ah=axes('position',get(gca,'position'),'visible','off');
legend(ah,ph2(1),'C_{39}','location',[0.36,0.77,0.1,0.1]); legend boxoff;
ah=axes('position',get(gca,'position'),'visible','off');
legend(ah,ph3(1),'C_{20}','location',[0.36,0.71,0.1,0.1]); legend boxoff;
ah=axes('position',get(gca,'position'),'visible','off');
legend(ah,ph4(1),'C_{1}', 'location',[0.353,0.65,0.1,0.1]); legend boxoff;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% the set of high histories 

file1  = strcat('e05-baseh-1-');
file2  = strcat('e05-baseh-20-');
file3  = strcat('e05-baseh-39-');

I1=9;I2=12;

%fout1  = strcat(fout1,'I',num2str(I2),'ABC');
fout1  = strcat(fout1,'I',num2str(I2));



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% high history 1

file=file1;

% lifetime variables
fend = 'In';
out = dlmread(strcat(file0,file,fend,fext));

thym  = out(:,1);
thm   = out(:,2)/10*2;
gm    = out(:,4:size(out,2));
In   = length(thym);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(file0,file,fend,fext));

uc_m = out(:,1);
tau_m= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(I2)); 
out  = dlmread(strcat(file0,file,fend,fext));

uctm = out(:,1);
tautm= out(:,2);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% high history 2

file=file2;

% lifetime variables
fend = 'In';
out = dlmread(strcat(file0,file,fend,fext));

thyp  = out(:,1);
thp   = out(:,2)/10*2;
gp    = out(:,4:size(out,2));
In   = length(thyp);
clear out;

% preceeding variables
fend = 'm'; 
out  = dlmread(strcat(file0,file,fend,fext));

uc_p = out(:,1);
tau_p= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(I2)); 
out  = dlmread(strcat(file0,file,fend,fext));

uctp = out(:,1);
tautp= out(:,2);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% high history 3

file=file3;

% lifetime variables
fend = 'In';
out = dlmread(strcat(file0,file,fend,fext));

thy  = out(:,1);
th   = out(:,2)/10*2;
g    = out(:,4:size(out,2));
In   = length(thy);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(file0,file,fend,fext));

uc_ = out(:,1);
tau_= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(I2)); 
out  = dlmread(strcat(file0,file,fend,fext));

uct = out(:,1);
taut= out(:,2);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% compute high histories' terms

Tautm = tautm./(ones(In,1)-tautm);
Tautp = tautp./(ones(In,1)-tautp);
Taut  = taut ./(ones(In,1)-taut );

G = g(:,I2);
for i=2:In
    G(i)=G(i-1)+G(i);
end
Gc    = ones(In,1)-G;
H     = Gc./(g(:,I2).*th);

Uctm   = uc_m./uctm(I2);
Uctp   = uc_p./uctp(I2);
Uct    = uc_ ./uct(I2);

Tautmm   = tau_m(I2)/(1-tau_m(I2));
Tautpm   = tau_p(I2)/(1-tau_p(I2));
Taut_m   = tau_(I2)/(1-tau_(I2));

Tautmterm = rho*Tautmm*Uctm;
Tautpterm = rho*Tautpm*Uctp;
Taut_term = rho*Taut_m*Uct;

Intratm = Tautm - Tautmterm;
Intratp = Tautp - Tautpterm;
Intrat  = Taut  - Taut_term;

% optional filtering 
Ctm = smooth(Intratm/(1+1/eps)./H,3,'moving');
Ctp = smooth(Intratp/(1+1/eps)./H,3,'moving');
Ct  = smooth(Intrat /(1+1/eps)./H,3,'moving');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%
subplot(2,2,4)
hold on
grid on
box on

plot(thy,Uct,'-r','LineWidth',lw);
plot(thyp,Uctp,'--b','LineWidth',lw);
plot(thym,Uctm,'-.k','LineWidth',lw);

axis tight
xlim([thy(1) thy(In-3)]);
ylim([0 5.7]);
xlabel('Labor earnings, $1000s');
title({'D: Intertemporal forces,','history of high earnings'});


%legend(   ph1(1),'B_t',   'location',[0.26,0.77,0.1,0.1]); legend boxoff;
%ah=axes('position',get(gca,'position'),'visible','off');
%legend(ah,ph2(1),'C_{39}','location',[0.36,0.77,0.1,0.1]); legend boxoff;
%ah=axes('position',get(gca,'position'),'visible','off');
%legend(ah,ph3(1),'C_{20}','location',[0.36,0.71,0.1,0.1]); legend boxoff;
%ah=axes('position',get(gca,'position'),'visible','off');
%legend(ah,ph4(1),'C_{1}', 'location',[0.353,0.65,0.1,0.1]); legend boxoff;


%%%%%%
subplot(2,2,3)
hold on
grid on
box on

plot(thy,Ct,'-r','LineWidth',lw/2);
plot(thyp,Ctp,'--b','LineWidth',lw/2);
plot(thym,Ctm,'-.k','LineWidth',lw/2);
plot(thy,H,'-.k','LineWidth',lw);

axis tight
xlim([thy(1) thy(In-3)]);
ylim([0 5.7]);
xlabel('Labor earnings, $1000s');
title({'C: Intratemporal forces,','history of high earnings'});


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(findall(gcf,'type','text'),'FontSize',Font,'FontName',FontN);
set(findall(gcf,'type','axes'),'FontSize',Font,'FontName',FontN);
set(gcf,'PaperPositionMode','auto');
print (gcf, '-depsc', fout1);
clear all;
close all;


