
% This file contains additional materials for 
% "Redistribution and Social Insurance".
% 
% This file constructs 2 sets of 3 histories
% from allocation .out files, 
% compares them to 2 static experiments,
% plots the experiments in the baseline case.
% 
% The allocation .out files are assumed to be in the same directory.
% 
% The .eps files are saved at the end 
% and existing .eps would be replaced.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;

% histories
history0  = 'ceslog';

history1  = strcat('e05-base9-1-');
history2  = strcat('e05-base9-20-');
history3  = strcat('e05-base9-39-');

h1=9;
h2=12; 

fout  = strcat('histexperiments-',history0,history1,num2str(h1),num2str(h2));
fext   = '.out';

% display parameters
lw = 3;
Font = 22;
FontN='Times New Roman';



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% experiment 1: static with the distribution set to
% the initial distribution for the baseline history

fend = 'St';
out  = dlmread(strcat(history0,history1,fend,fext));

ucSt = out(:,1);
tauSt= out(:,2);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 1

file=history1;

% lifetime variables
fend = 'In';
out = dlmread(strcat(history0,file,fend,fext));
thy  = out(:,1);
g    = out(:,4:size(out,2));
In   = length(thy);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(history0,file,fend,fext));
    
uc_ = out(:,1);
tau_= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(h1)); 
out  = dlmread(strcat(history0,file,fend,fext));
    
uct(:,h1) = out(:,1);
taut(:,h1)= out(:,2);
clear out;

fend = strcat('',num2str(h2)); 
out  = dlmread(strcat(history0,file,fend,fext));

uct(:,h2) = out(:,1);
taut(:,h2)= out(:,2);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 2

file=history2;

% lifetime variables
fend = 'In';
out = dlmread(strcat(history0,file,fend,fext));
thyp  = out(:,1);
gp    = out(:,4:size(out,2));
In   = length(thyp);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(history0,file,fend,fext));
uc_p = out(:,1);
tau_p= out(:,2);
clear out;

% current variabes
fend = strcat('',num2str(h1)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctp(:,h1) = out(:,1);
tautp(:,h1)= out(:,2);
clear out;

fend = strcat('',num2str(h2)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctp(:,h2) = out(:,1);
tautp(:,h2)= out(:,2);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 3

file=history3;

% lifetime variables
fend = 'In';
out = dlmread(strcat(history0,file,fend,fext));
thypp  = out(:,1);
gpp    = out(:,4:size(out,2));
In   = length(thypp);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(history0,file,fend,fext));
uc_pp = out(:,1);
tau_pp= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(h1)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctpp(:,h1) = out(:,1);
tautpp(:,h1)= out(:,2);
clear out;

fend = strcat('',num2str(h2)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctpp(:,h2) = out(:,1);
tautpp(:,h2)= out(:,2);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure  ('units','normalized','outerposition',[0 0 .75 1])   
%figure  ('units','normalized','outerposition',[0 .1 .6 .36])


%%%%%%
subplot(2,2,1)
hold on
grid on
box on

plot(thypp,tautpp(:,h1),'-r','LineWidth',lw);
plot(thyp,tautp(:,h1),'--b','LineWidth',lw);
plot(thy,taut(:,h1),'-.k','LineWidth',lw);
plot(thy,tauSt,'--k','LineWidth',lw/3);

axis tight
xlim([thy(1) thy(In-3)]);
ylim([.2 .81]);
%legend('t=39','t=20','t=1','static_experiment','location','southeast');
%legend boxoff;
%columns(2,'t=39','t=20','t=1','static_experiment');
xlabel('Labor earnings, $1000s');
%ylabel('\tau_t, tau_st');
title({'A: Labor distortions,','history of low earnings'});



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% the second set of three histories

history0  = 'ceslog'; 

history1  = strcat('e05-base12-1-');
history2  = strcat('e05-base12-20-');
history3  = strcat('e05-base12-39-');

h1=9;
h2=12; 



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% experiment 2: static with the distribution set to
% the initial distribution of the baseline histories

fend = 'St';
out  = dlmread(strcat(history0,history1,fend,fext));

ucSt = out(:,1);
tauSt= out(:,2);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 1

file=history1;

% lifetime variables
fend = 'In';
out = dlmread(strcat(history0,file,fend,fext));
thy  = out(:,1);
g    = out(:,4:size(out,2));
In   = length(thy);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(history0,file,fend,fext));
    
uc_ = out(:,1);
tau_= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(h1)); 
out  = dlmread(strcat(history0,file,fend,fext));
    
uct(:,h1) = out(:,1);
taut(:,h1)= out(:,2);
clear out;

fend = strcat('',num2str(h2)); 
out  = dlmread(strcat(history0,file,fend,fext));

uct(:,h2) = out(:,1);
taut(:,h2)= out(:,2);
clear out;

fend = 'S';
out  = dlmread(strcat(history0,file,fend,fext));

tautS = out(:,1);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 2

file=history2;

% lifetime variables
fend = 'In';
out = dlmread(strcat(history0,file,fend,fext));
thyp  = out(:,1);
gp    = out(:,4:size(out,2));
In   = length(thyp);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(history0,file,fend,fext));
uc_p = out(:,1);
tau_p= out(:,2);
clear out;

% current variabes
fend = strcat('',num2str(h1)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctp(:,h1) = out(:,1);
tautp(:,h1)= out(:,2);
clear out;

fend = strcat('',num2str(h2)); 
out  = dlmread(strcat(history0,file,fend,fext));
uctp(:,h2) = out(:,1);
tautp(:,h2)= out(:,2);
clear out;

fend = 'S';
out  = dlmread(strcat(history0,file,fend,fext));

tautSp = out(:,1);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 3

file=history3;

% lifetime variables
fend = 'In';
out = dlmread(strcat(history0,file,fend,fext));
thypp  = out(:,1);
gpp    = out(:,4:size(out,2));
In   = length(thypp);
clear out;

% preceeding variables
fend = 'm';
out  = dlmread(strcat(history0,file,fend,fext));
uc_pp = out(:,1);
tau_pp= out(:,2);
clear out;

% current variables
fend = strcat('',num2str(h1)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctpp(:,h1) = out(:,1);
tautpp(:,h1)= out(:,2);
clear out;

fend = strcat('',num2str(h2)); 
out  = dlmread(strcat(history0,file,fend,fext));

uctpp(:,h2) = out(:,1);
tautpp(:,h2)= out(:,2);
clear out;

fend = 'S';
out  = dlmread(strcat(history0,file,fend,fext));

tautSpp = out(:,1);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%
subplot(2,2,2)
hold on
grid on
box on

ph1 = plot(thypp,tautpp(:,h2),'-r','LineWidth',lw);
ph2 = plot(thyp,tautp(:,h2),'--b','LineWidth',lw);
ph3 = plot(thy,taut(:,h2),'-.k','LineWidth',lw);
ph4 = plot(thy,tauSt,'--k','LineWidth',lw/3);

axis tight
xlim([thy(1) thy(In-3)]);
ylim([.2 .81]);
xlabel('Labor earnings, $1000s');
%ylabel('\tau_t, tau_st');
%legend('t=39','t=20','t=1','static','location','southeast');
%legend boxoff;
title({'B: Labor distortions,','history of high earnings'});

legend(   ph1(1),'t=39',  'location',[0.67,0.64,0.1,0.1]); legend boxoff;
ah=axes('position',get(gca,'position'),'visible','off');
legend(ah,ph2(1),'t=20',  'location',[0.67,0.59,0.1,0.1]); legend boxoff;
ah=axes('position',get(gca,'position'),'visible','off');
legend(ah,ph3(1),'t=1 ',  'location',[0.78,0.64,0.1,0.1]); legend boxoff;
ah=axes('position',get(gca,'position'),'visible','off');
legend(ah,ph4(1),'static','location',[0.79,0.59,0.1,0.1]); legend boxoff;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(findall(gcf,'type','text'),'FontSize',Font,'FontName',FontN);
set(findall(gcf,'type','axes'),'FontSize',Font,'FontName',FontN);
saveas(gcf,fout,'fig')
set(gcf,'PaperPositionMode','auto');
print (gcf, '-depsc', fout);
clear all;
close all;


