% 
% This file contains additional materials for 
% "Redistribution and Social Insurance".
% 
% This file reads simulated averages 
% from simulation .out files for a set of 3 histories
% and plots the average distortions in the baseline case.
% 
% This file can also be used to produce the robustness
% figure for the averages in the appendix by 
% uncommenting as indicated below
% 
% The allocation .out files need to be 
% already in the same directory.
% 
% The .eps files are saved at the end 
% and existing files would be replaced.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;

% histories
file0  = 'ceslog';

file1  = strcat('e05-basesim-39-');
file2  = strcat('e05-basesim-20-');
file3  = strcat('e05-basesim-1-');

I=12;Ic=0;

fext   = '.out';
fout1  = strcat('historiesavg-',file0,file1);
%uncomment for appendix robustness figure:
%fout1  = strcat('historiesavg-',file0,file1,'th'); 

% display parameters
lw = 3;
Font = 22;
FontN='Times New Roman';



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file1

file=file1;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thypp  = out(:,1);
% th   = out(:,1);
In   = length(thypp);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvgpp = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvgpp = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file2

file=file2;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thyp  = out(:,1);
% th   = out(:,1);
In   = length(thyp);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvgp = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvgp = out(:,1);
clear out;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file3

file=file3;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thy  = out(:,1);
%uncomment for appendix robustness figure:
th   = out(:,2);
In   = length(thy);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvg = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvg = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure  ('units','normalized','outerposition',[0 0 .75 .95])
%figure  ('units','normalized','outerposition',[0 .1 .7 .5])


%%%%%%
subplot(2,2,1)
hold on
grid on
box on

%comment out for appendix robustness figure:
plot(thypp,tautAvgpp,'-r','LineWidth',lw);
plot(thyp,tautAvgp,'--b','LineWidth',lw);
plot(thy,tautAvg,'-.k','LineWidth',lw);

%uncomment for appendix robustness figure:
% plot(th,tautAvgpp,'-r','LineWidth',lw);
% plot(th,tautAvgp,'--b','LineWidth',lw);
% plot(th,tautAvg,'-.k','LineWidth',lw);

axis tight
xlim([thy(3) thy(In-3)]);
%uncomment for appendix robustness figure:
%xlim([0.5 21]); %th xlim
ylim([.2 .8]);
xlabel('Labor earnings, $1000s');
%uncomment for appendix robustness figure:
%xlabel('\theta');
title({'A: Average labor distortions'});


%%%%%%
subplot(2,2,2)
hold on
grid on
box on

%comment out for appendix robustness figure:
plot(thypp,tautSAvgpp,'-r','LineWidth',lw);
plot(thyp,tautSAvgp,'--b','LineWidth',lw);
plot(thy,tautSAvg,'-.k','LineWidth',lw);

%uncomment for appendix robustness figure:
% plot(th,tautSAvgpp,'-r','LineWidth',lw);
% plot(th,tautSAvgp,'--b','LineWidth',lw);
% plot(th,tautSAvg,'-.k','LineWidth',lw);

axis tight
xlim([thy(3) thy(In-3)]);
%uncomment for appendix robustness figure:
%xlim([0.5 21]); %th xlim
ylim([0 .024]);
set(gca,'YTick',0:.005:.02);
legend('t=39','t=20','t=1','location','east');
legend boxoff;
xlabel('Labor earnings, $1000s');
%uncomment for appendix robustness figure:
%xlabel('\theta');
title({'B: Average savings distortions'});



%%%%%%
saveas(gcf,fout1,'fig')
set(findall(gcf,'type','text'),'FontSize',Font,'FontName',FontN);
set(findall(gcf,'type','axes'),'FontSize',Font,'FontName',FontN);
set(gcf,'PaperPositionMode','auto');
print (gcf, '-depsc', fout1);
clear all;
close all;


