 
% This file contains additional materials for 
% "Redistribution and Social Insurance".
% 
% This file constructs 2 sets of 3 histories
% from allocation .out files,
% 1 for baseline case and 1 for lognormal experiment.
% It then loads the averages for the two cases
% and plots the distortions and the averages.
% 
% The allocation .out files are assumed to be 
% already in the same directory.
% 
% The .eps files are saved at the end 
% and existing files would be replaced.



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all;
close all;

% initial baseline histories
history0  = 'ceslog';

history1  = strcat('e05-base9-1-');
history2  = strcat('e05-base9-20-');
history3  = strcat('e05-base9-39-');

h1=9;
h2=12; 

fout  = strcat('historiesavglogn-',history0,history1,num2str(h1),num2str(h2));
fext   = '.out';

% display parameters
lw = 3;
Font = 22;
FontN='Times New Roman';


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 1

hist11

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 2

hist12

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 3

hist13


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure  ('units','normalized','outerposition',[0 0 .75 1])   
%figure  ('units','normalized','outerposition',[0 .1 .6 .36])


%%%%%%
subplot(2,2,1)
hold on
grid on
box on

plot(thypp,tautpp(:,h1),'-r','LineWidth',lw/3);
plot(thyp,tautp(:,h1),'--b','LineWidth',lw/3);
plot(thy,taut(:,h1),'-.k','LineWidth',lw/3);

axis tight
xlim([thy(3) thy(In-3)]);
ylim([.1 .81]);
%legend('t=39','t=20','t=1','f_t','location','southeast');
%legend boxoff;
%columns(2,'t=39','t=20','t=1','f_t');
%ylabel('\tau_t, f_t');
title({'A: Labor distortions,','history of low earnings'});


%%%%%%
subplot(2,2,2)
hold on
grid on
box on

plot(thypp,tautSpp,'-r','LineWidth',lw/3);
plot(thyp,tautSp,'--b','LineWidth',lw/3);
plot(thy,tautS,'-.k','LineWidth',lw/3);

axis tight
xlim([thy(3) thy(In-3)]);
ylim([0 .024]);
set(gca,'YTick',0:.005:.02);
legend('t=39','t=20','t=1','location','southeast');
legend boxoff;
%ylabel('\tau^s_t');
title({'B: Savings distortions,','history of low earnings'});
%commontitle({'Distortions,','history of low earnings'});



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% the second set of three histories
% for lognormal experiment

history0  = 'ceslog'; 

history1  = strcat('e05-logn9-1-');
history2  = strcat('e05-logn9-20-');
history3  = strcat('e05-logn9-39-');

h1=9;
h2=9; 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 1

hist21

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 2

hist22

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% history 3

hist23


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,2,1)

plot(thypp,tautpp(:,h2),'-r','LineWidth',lw);
plot(thyp,tautp(:,h2),'--b','LineWidth',lw);
plot(thy,taut(:,h2),'-.k','LineWidth',lw);


%%%%%%
subplot(2,2,2)

plot(thypp,tautSpp,'-r','LineWidth',lw);
plot(thyp,tautSp,'--b','LineWidth',lw);
plot(thy,tautS,'-.k','LineWidth',lw);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% histories for averages
% for the baseline case

file0  = 'ceslog';

file1  = strcat('e05-basesim-39-');
file2  = strcat('e05-basesim-20-');
file3  = strcat('e05-basesim-1-');

I=12;Ic=0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file1

file=file1;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thypp  = out(:,1);
% th   = out(:,1);
In   = length(thypp);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvgpp = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvgpp = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file2

file=file2;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thyp  = out(:,1);
% th   = out(:,1);
In   = length(thyp);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvgp = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvgp = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file3

file=file3;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thy  = out(:,1);
th   = out(:,2);
In   = length(thy);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvg = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvg = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%
subplot(2,2,3)
hold on
grid on
box on

plot(thypp,tautAvgpp,'-r','LineWidth',lw/3);
plot(thyp,tautAvgp,'--b','LineWidth',lw/3);
plot(thy,tautAvg,'-.k','LineWidth',lw/3);

axis tight
xlim([thy(3) thy(In-3)]);
ylim([.1 .8]);
xlabel('Labor earnings, $1000s');
title({'C: Average labor distortions'});


%%%%%%
subplot(2,2,4)
hold on
grid on
box on

plot(thypp,tautSAvgpp,'-r','LineWidth',lw/3);
plot(thyp,tautSAvgp,'--b','LineWidth',lw/3);
plot(thy,tautSAvg,'-.k','LineWidth',lw/3);

axis tight
xlim([thy(3) thy(In-3)]);
ylim([0 .024]);
set(gca,'YTick',0:.005:.02);
% legend('t=39','t=20','t=1','location','east');
% legend boxoff;
xlabel('Labor earnings, $1000s');
title({'D: Average savings distortions'});



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% the second set of histories for averages
% for the lognormal experiment

file0  = 'ceslog';

file1  = strcat('e05-lognsim-39-');
file2  = strcat('e05-lognsim-20-');
file3  = strcat('e05-lognsim-1-');

I=9;Ic=0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file1

file=file1;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thypp  = out(:,1);
% th   = out(:,1);
In   = length(thypp);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvgpp = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvgpp = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file2

file=file2;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thyp  = out(:,1);
% th   = out(:,1);
In   = length(thyp);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvgp = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvgp = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% averages for the history in file3

file=file3;

fend = 'thy';
out = dlmread(strcat(file0,file,fend,fext));

thy  = out(:,1);
th   = out(:,2);
In   = length(thy);
clear out;

fend = 'wavg';
out = dlmread(strcat(file0,file,fend,fext));

tautAvg = out(:,1);
clear out;

fend = 'wavgS';
out = dlmread(strcat(file0,file,fend,fext));

tautSAvg = out(:,1);
clear out;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%
subplot(2,2,3)

plot(thypp,tautAvgpp,'-r','LineWidth',lw);
plot(thyp,tautAvgp,'--b','LineWidth',lw);
plot(thy,tautAvg,'-.k','LineWidth',lw);

%%%%%%
subplot(2,2,4)

plot(thypp,tautSAvgpp,'-r','LineWidth',lw);
plot(thyp,tautSAvgp,'--b','LineWidth',lw);
plot(thy,tautSAvg,'-.k','LineWidth',lw);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
set(findall(gcf,'type','text'),'FontSize',Font,'FontName',FontN);
set(findall(gcf,'type','axes'),'FontSize',Font,'FontName',FontN);
saveas(gcf,fout,'fig')
set(gcf,'PaperPositionMode','auto');
print (gcf, '-depsc', fout);
clear all;
close all;


